@@ -31,22 +31,23 @@ using namespace std;
 
 #include "libnormaliz/libnormaliz.h"
 #include "libnormaliz/cone.h"
+#include "libnormaliz/output.h"
 using namespace libnormaliz;
 
 #include "normaliz.h"
 #include "options.h"
-#include "output.h"
-
 
 OptionsHandler::OptionsHandler() {
     project_name_set = false;
     output_dir_set=false;
     write_extra_files = false, write_all_files = false;
-        // use_Big_Integer = false;
-        use_long_long = false;
-        ignoreInFileOpt = false;
-        nmzInt_E = false, nmzInt_I = false, nmzInt_L = false;
+    // use_Big_Integer = false;
+    use_long_long = false;
+    ignoreInFileOpt = false;
     nr_threads = 0;
+    no_ext_rays_output=false;
+    no_supp_hyps_output=false;
+    no_matrices_output=false;
 }
 
 
@@ -68,8 +69,9 @@ bool OptionsHandler::handle_commandline(int argc, char* argv[]) {
                         #ifdef _OPENMP
                         string Threads = argv[i];
                         Threads.erase(0,3);
-                        if ( (istringstream(Threads) >> nr_threads) && nr_threads > 0) {
-                            omp_set_num_threads(nr_threads);
+                        if ( (istringstream(Threads) >> nr_threads) && nr_threads >= 0) {
+                            set_thread_limit(nr_threads);
+                            // omp_set_num_threads(nr_threads); -- now in cone.cpp
                         } else {
                             cerr<<"Error: Invalid option string "<<argv[i]<<endl;
                         exit(1);
@@ -144,6 +146,9 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
                 to_compute.set(ConeProperty::Triangulation);
                 // to_compute.set(ConeProperty::Multiplicity);
                 break;
+            case 'F':
+                to_compute.set(ConeProperty::Descent);
+                break;
             case 's':
                 to_compute.set(ConeProperty::SupportHyperplanes);
                 break;
@@ -156,6 +161,9 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
             case 'v':
                 to_compute.set(ConeProperty::Multiplicity);
                 break;
+            case 'V':
+                to_compute.set(ConeProperty::Volume);
+                break;
             case 'n':
                 to_compute.set(ConeProperty::HilbertBasis);
                 to_compute.set(ConeProperty::Multiplicity);
@@ -219,19 +227,14 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
                 cerr<<"Error: Option -x=<T> has to be separated from other options"<<endl;
                 exit(1);
                 break;
-            case 'I':  //nmzIntegrate -I (integrate)
-                nmzInt_I = true;
-                to_compute.set(ConeProperty::Triangulation);
-                to_compute.set(ConeProperty::Multiplicity);
+            case 'I': 
+                to_compute.set(ConeProperty::Integral);
                 break;
-            case 'L':  //nmzIntegrate -L (leading term)
-                nmzInt_L = true;
-                to_compute.set(ConeProperty::Triangulation);
-                to_compute.set(ConeProperty::Multiplicity);
+            case 'L': 
+                to_compute.set(ConeProperty::VirtualMultiplicity);
                 break;
-            case 'E':  //nmzIntegrate -E (Ehrhart series)
-                nmzInt_E = true;
-                to_compute.set(ConeProperty::StanleyDec);
+            case 'E': 
+                to_compute.set(ConeProperty::WeightedEhrhartSeries);
                 break;
             case 'i':
                 ignoreInFileOpt=true;
@@ -251,6 +254,15 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
             case 'X':
                 to_compute.set(ConeProperty::NoSymmetrization);
                 break;
+            case 'G':
+                to_compute.set(ConeProperty::IsGorenstein);
+                break;
+            case 'j':
+                to_compute.set(ConeProperty::Projection);
+                break;
+            case 'J':
+                to_compute.set(ConeProperty::ProjectionFloat);
+                break;
             default:
                 cerr<<"Error: Unknown option -"<<ShortOptions[i]<<endl;
                 exit(1);
@@ -299,6 +311,18 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
             use_long_long=true;
             continue;
         }
+        if(LongOptions[i]=="NoExtRaysOutput"){
+            no_ext_rays_output=true;
+            continue;
+        }
+        if(LongOptions[i]=="NoSuppHypsOutput"){
+            no_supp_hyps_output=true;
+            continue;
+        }
+        if(LongOptions[i]=="NoMatricesOutput"){
+            no_matrices_output=true;
+            continue;
+        }
         if(LongOptions[i]=="ignore"){
             ignoreInFileOpt=true;
             continue;
@@ -336,6 +360,12 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
 
 template<typename Integer>
 void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
+    if(no_ext_rays_output)
+        Out.set_no_ext_rays_output();
+    if(no_supp_hyps_output)
+        Out.set_no_supp_hyps_output();
+    if(no_matrices_output)
+        Out.set_no_matrices_output();
     if(write_all_files) {
         Out.set_write_all_files();
     } else if (write_extra_files) {
@@ -351,6 +381,11 @@ void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
         Out.set_write_tgn(true);
         Out.set_write_inv(true);
     }
+    if (to_compute.test(ConeProperty::FaceLattice)) {
+        Out.set_write_fac(true);
+        Out.set_write_cst(true);
+        Out.set_write_inv(true);
+    }
     for(size_t i=0;i<OutFiles.size();++i){
         if(OutFiles[i]=="gen"){
             Out.set_write_gen(true);
@@ -405,44 +440,8 @@ void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
     Out.set_name(output_file);
 }
 
-bool OptionsHandler::anyNmzIntegrateOption() const {
-    return nmzInt_E || nmzInt_I || nmzInt_L;
-}
-
-string OptionsHandler::getNmzIntegrateOptions() const {
-    string nmz_options;
-    if (verbose) {
-        nmz_options.append(" -c");
-    }
-    if (nr_threads > 0) {
-        nmz_options.append(" -x=");
-        ostringstream convert;
-        convert << nr_threads;
-        nmz_options.append(convert.str());
-    }
-    if (nmzInt_E) {
-        nmz_options.append(" -E");
-    }
-    if (nmzInt_L) {
-        nmz_options.append(" -L");
-    }
-    if (nmzInt_I) {
-        nmz_options.append(" -I");
-    }
-    nmz_options.append(" \"");
-    nmz_options.append(project_name);
-    nmz_options.append("\"");
-    if(output_dir_set){
-        nmz_options.append(" \"");
-        nmz_options.append("--OutputDir="+output_dir);
-        nmz_options.append("\"");
-    }
-    return nmz_options;
-}
-
 bool OptionsHandler::activateDefaultMode() {
-    if (to_compute.goals().none() && !to_compute.test(ConeProperty::DualMode) 
-                                  && !to_compute.test(ConeProperty::Approximate)) {
+    if (to_compute.goals().none() && !to_compute.test(ConeProperty::DualMode) ){
         to_compute.set(ConeProperty::DefaultMode);
         return true;
     }
@@ -466,4 +465,4 @@ string pureName(const string& fullName){
     // exit(1);
     return(fullName.substr(found,length));  	
 
-}
+}
\ No newline at end of file
