@@ -29,10 +29,10 @@ using namespace std;
 
 #include "libnormaliz/libnormaliz.h"
 #include "libnormaliz/cone.h"
+#include "libnormaliz/output.h"
 using namespace libnormaliz;
 
 //#include "Input.h"
-#include "output.h"
 
 #ifndef NMZ_OPTIONS_H
 #define NMZ_OPTIONS_H
@@ -53,11 +53,6 @@ public:
     template<typename Integer>
     void applyOutputOptions(Output<Integer>& Out);
 
-    // returns whether any nmzIntegrate option is set
-    bool anyNmzIntegrateOption() const;
-
-    string getNmzIntegrateOptions() const;
-
     bool isFilenameSet() const {
         return project_name_set;
     }
@@ -83,6 +78,18 @@ public:
     void activateInputFileLongLong() {
         if (!ignoreInFileOpt) use_long_long = true;
     }
+    
+    void activateNoExtRaysOutput() {
+        if (!ignoreInFileOpt) no_ext_rays_output = true;
+    }
+    
+    void activateNoMatricesOutput() {
+        if (!ignoreInFileOpt) no_matrices_output = true;
+    }
+    
+    void activateNoSuppHypsOutput() {
+        if (!ignoreInFileOpt) no_supp_hyps_output = true;
+    }
 
     const ConeProperties& getToCompute() const {
         return to_compute;
@@ -94,6 +101,18 @@ public:
     bool isUseLongLong() const {
         return use_long_long;
     }
+    
+    bool isNoExtRaysOutput() const {
+        return no_ext_rays_output;
+    }
+    
+    bool isNoMatricesOutput() const {
+        return no_matrices_output;
+    }
+    
+    bool isNoSuppHypsOutput() const {
+        return no_supp_hyps_output;
+    }
 
     const string& getProjectName() const {
         return project_name;
@@ -109,16 +128,19 @@ public:
 //---------------------------------------------------------------------------
 
 private:
-	bool project_name_set;
-        bool output_dir_set;
-	string project_name;
-        string output_dir;
-        string output_file;
+    bool project_name_set;
+    bool output_dir_set;
+    string project_name;
+    string output_dir;
+    string output_file;
 
-	// bool use_Big_Integer; now in ConeProperty
-	bool use_long_long;
+    // bool use_Big_Integer; now in ConeProperty
+    bool use_long_long;
+    bool no_ext_rays_output;
+    bool no_supp_hyps_output;
+    bool no_matrices_output;
+    
     bool ignoreInFileOpt;
-    bool nmzInt_E, nmzInt_I, nmzInt_L;
 
     int nr_threads;
 
